<?php

namespace Drupal\project_wiki\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\project_wiki\Plugin\ProjectWikiContentPluginManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for Project Wiki routes.
 */
class ProjectWikiController extends ControllerBase {

  /**
   * The plugin manager instance.
   *
   * @var \Drupal\project_wiki\Plugin\ProjectWikiContentPluginManager
   */
  protected $pluginManager;

  /**
   * CaptchaExamplesForm constructor.
   *
   * @param \Drupal\project_wiki\Plugin\ProjectWikiContentPluginManager $pluginManager
   *   The plugin manager instance.
   */
  public function __construct(ProjectWikiContentPluginManager $pluginManager) {
    $this->pluginManager = $pluginManager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('plugin.manager.project_wiki_content')
    );
  }

  /**
   * Builds the response.
   */
  public function build(): array {
    $projectWikiContentValueObjectInstances = $this->pluginManager->createInstances();
    $result = [];

    if (!empty($projectWikiContentValueObjectInstances)) {
      foreach ($projectWikiContentValueObjectInstances as $projectWikiContentValueObjectInstance) {
        $projectWikiValueObjects = $projectWikiContentValueObjectInstance->getValueObjects();
        foreach ($projectWikiValueObjects as $projectWikiValueObject) {
          if (!$projectWikiValueObject->isDeveloperContent() || parent::currentUser()->hasPermission('view project wiki developer content')) {
            $result[] = $projectWikiValueObject;
          }
        }
      }
    }

    // Filter out any empty entries through (e.g. when no entries exist):
    $result = array_filter($result);

    $this->moduleHandler()->alter('project_wiki_entity_content_value_objects', $result);

    if (empty($result)) {
      return [
        '#type' => 'markup',
        '#markup' => '<strong>There are currently no entries in the Project Wiki.</strong>',
      ];
    }

    $build['list'] = [
      '#theme' => 'project_wiki_list',
      '#projectWikiEntries' => $result,
      '#attached' => [
        'library' => [
          'project_wiki/global',
          'project_wiki/search',
        ],
      ],
    ];
    return $build;
  }

}
